chaos library
Classes
- PersistentRandom
- A Random number generator where state can be saved and restored.
- Random
- A generator of random bool, int, or double values.
-
SeedableGenerator<
T extends Random> -
A factory class that creates Random instances of
Tthat can be seeded. - SequenceRandom
- A fixed number generator that produces a sequence of predetermined numbers.
- Xoshiro128
- A base class for the Xoshiro128 family of random number generators.
- Xoshiro128P
- A 32-bit Xoshiro128+ pseudorandom number generator (PRNG).
- Xoshiro128PP
- A 32-bit Xoshiro128++ pseudorandom number generator (PRNG).
Constants
-
defaultRandom
→ const SeedableGenerator<
Random> - A default instance of SeedableGenerator that uses Random as the PRNG.
-
systemRandom
→ const SeedableGenerator<
Random> - A default instance of SeedableGenerator that uses Random as the PRNG.
-
xoshiro128P
→ const SeedableGenerator<
Xoshiro128P> - Creates instances of the Xoshiro128P random number generator.
-
xoshiro128PP
→ const SeedableGenerator<
Xoshiro128PP> - Creates instances of the Xoshiro128PP random number generator.